pub trait MigrationRunnerExecutor {
// Required method
fn run_migrations<'a>(
&'a self,
runner: &'a Runner,
) -> BoxFuture<'a, Result<(), ErrorPtr>>;
}Expand description
Since Runner requires a concrete DB client to execute migrations, an abstraction over all possible clients needs to exist, which will execute the actual run operation with a concrete client. This trait is such abstraction. By default, all MigrationRunnerExecutors will be called to run migrations in unspecified order.